/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.felix.dm.lambda.callbacks;

import java.util.Objects;

import org.osgi.framework.Bundle;

/**
 * Represents a callback(Bundle) on an Object instance.
 * 
 * @author <a href="mailto:dev@felix.apache.org">Felix Project Team</a>
 */
@FunctionalInterface
public interface InstanceCbBundle extends SerializableLambda {
    /**
     * Handles the given argument.
     * @param bundle the callback parameter
     */
    void accept(Bundle bundle);

    default InstanceCbBundle andThen(InstanceCbBundle after) {
        Objects.requireNonNull(after);
        return (Bundle bundle) -> {
            accept(bundle);
            after.accept(bundle);
        };
    }
}
